summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAdrian Knoth <aknoth@google.com>2018-02-25 18:45:49 +0100
committerAdrian Knoth <aknoth@google.com>2018-02-25 18:47:52 +0100
commit6ccfdc1058f9cbd79d636a822163eda76eb4eb02 (patch)
treef056a15ac7a3d5a67654fcc618708603b0cd17c0
parenta5e6585dd391220d56fbe4704df71544ad83ba6e (diff)
downloadjack2-6ccfdc1058f9cbd79d636a822163eda76eb4eb02.tar.gz
Mass-fix spelling errors
Flagged by the Debian QA tool. Mostly automatic search-n-replace of the mistakes flagged.
-rw-r--r--common/JackInternalSessionLoader.cpp2
-rw-r--r--common/JackMidiRawInputWriteQueue.cpp2
-rw-r--r--common/JackPort.cpp2
-rw-r--r--common/jack/jack.h2
-rw-r--r--common/netjack.c12
-rw-r--r--common/netjack_packet.c4
-rw-r--r--dbus/controller_iface_patchbay.c2
-rw-r--r--doxyfile.in2
-rw-r--r--example-clients/alsa_in.c2
-rw-r--r--example-clients/alsa_out.c2
-rw-r--r--example-clients/netsource.c2
-rw-r--r--man/alsa_in.02
-rw-r--r--man/jack_simple_client.02
-rw-r--r--man/jackd.02
-rw-r--r--tests/test.cpp6
-rw-r--r--windows/JackWinNamedPipeClientChannel.cpp2
16 files changed, 24 insertions, 24 deletions
diff --git a/common/JackInternalSessionLoader.cpp b/common/JackInternalSessionLoader.cpp
index 5a438e72..61d28ab5 100644
--- a/common/JackInternalSessionLoader.cpp
+++ b/common/JackInternalSessionLoader.cpp
@@ -71,7 +71,7 @@ int JackInternalSessionLoader::Load(const char* file)
* Therefore only compare the first letter of the command.
*/
} else {
- jack_error("JACK internal session file %s line %u contains unkown command '%s'. Ignoring the line!", file, linenr, line.c_str());
+ jack_error("JACK internal session file %s line %u contains unknown command '%s'. Ignoring the line!", file, linenr, line.c_str());
}
}
diff --git a/common/JackMidiRawInputWriteQueue.cpp b/common/JackMidiRawInputWriteQueue.cpp
index 5c76f8b4..e5cb59e3 100644
--- a/common/JackMidiRawInputWriteQueue.cpp
+++ b/common/JackMidiRawInputWriteQueue.cpp
@@ -83,7 +83,7 @@ JackMidiRawInputWriteQueue::HandleEventLoss(jack_midi_event_t *event)
{
jack_error("JackMidiRawInputWriteQueue::HandleEventLoss - A %d byte MIDI "
"event scheduled for frame '%d' could not be processed because "
- "the write queue cannot accomodate an event of that size. The "
+ "the write queue cannot accommodate an event of that size. The "
"event has been discarded.", event->size, event->time);
}
diff --git a/common/JackPort.cpp b/common/JackPort.cpp
index 417882d4..30c0f955 100644
--- a/common/JackPort.cpp
+++ b/common/JackPort.cpp
@@ -97,7 +97,7 @@ void JackPort::SetLatency(jack_nframes_t nframes)
fLatency = nframes;
/* setup the new latency values here,
- * so we dont need to change the backend codes.
+ * so we don't need to change the backend codes.
*/
if (fFlags & JackPortIsOutput) {
fCaptureLatency.min = nframes;
diff --git a/common/jack/jack.h b/common/jack/jack.h
index bf50e602..05ef7959 100644
--- a/common/jack/jack.h
+++ b/common/jack/jack.h
@@ -1082,7 +1082,7 @@ size_t jack_port_type_get_buffer_size (jack_client_t *client, const char *port_t
* expressed a min/max pair.
*
* In most common setups, the minimum and maximum latency
- * are the same, but this design accomodates more complex
+ * are the same, but this design accommodates more complex
* routing, and allows applications (and thus users) to
* detect cases where routing is creating an anomalous
* situation that may either need fixing or more
diff --git a/common/netjack.c b/common/netjack.c
index 022fa8bc..36337995 100644
--- a/common/netjack.c
+++ b/common/netjack.c
@@ -199,7 +199,7 @@ int netjack_wait( netjack_driver_state_t *netj )
//XXX: hmm... i need to remember why resync_threshold wasnt right.
//if( offset < netj->resync_threshold )
if( offset < 10 ) {
- // ok. dont do nothing. we will run without data.
+ // ok. don't do nothing. we will run without data.
// this seems to be one or 2 lost packets.
//
// this can also be reordered packet jitter.
@@ -283,7 +283,7 @@ int netjack_wait( netjack_driver_state_t *netj )
netj->running_free = 1;
- // when we really dont see packets.
+ // when we really don't see packets.
// reset source address. and open possibility for new master.
// maybe dsl reconnect. Also restart of netsource without fix
// reply address changes port.
@@ -597,7 +597,7 @@ netjack_driver_state_t *netjack_init (netjack_driver_state_t *netj,
// Fill in netj values.
// might be subject to autoconfig...
- // so dont calculate anything with them...
+ // so don't calculate anything with them...
netj->sample_rate = sample_rate;
netj->period_size = period_size;
@@ -697,7 +697,7 @@ netjack_startup( netjack_driver_state_t *netj )
socklen_t address_size = sizeof (struct sockaddr_in);
#endif
//jack_info ("Waiting for an incoming packet !!!");
- //jack_info ("*** IMPORTANT *** Dont connect a client to jackd until the driver is attached to a clock source !!!");
+ //jack_info ("*** IMPORTANT *** Don't connect a client to jackd until the driver is attached to a clock source !!!");
while(1) {
if( ! netjack_poll( netj->sockfd, 1000 ) ) {
@@ -788,7 +788,7 @@ netjack_startup( netjack_driver_state_t *netj )
if( netj->bitdepth == CELT_MODE ) {
// celt mode.
- // TODO: this is a hack. But i dont want to change the packet header.
+ // TODO: this is a hack. But i don't want to change the packet header.
netj->resample_factor = (netj->resample_factor * netj->period_size * 1024 / netj->sample_rate / 8) & (~1);
netj->resample_factor_up = (netj->resample_factor_up * netj->period_size * 1024 / netj->sample_rate / 8) & (~1);
@@ -796,7 +796,7 @@ netjack_startup( netjack_driver_state_t *netj )
netj->net_period_up = netj->resample_factor_up;
} else if( netj->bitdepth == OPUS_MODE ) {
// Opus mode.
- // TODO: this is a hack. But i dont want to change the packet header, either
+ // TODO: this is a hack. But i don't want to change the packet header, either
netj->net_period_down = (netj->resample_factor * netj->period_size * 1024 / netj->sample_rate / 8) & (~1);
netj->net_period_up = (netj->resample_factor_up * netj->period_size * 1024 / netj->sample_rate / 8) & (~1);
} else {
diff --git a/dbus/controller_iface_patchbay.c b/dbus/controller_iface_patchbay.c
index b0de0892..8e754afc 100644
--- a/dbus/controller_iface_patchbay.c
+++ b/dbus/controller_iface_patchbay.c
@@ -1528,7 +1528,7 @@ jack_controller_graph_order_callback(
if (patchbay_ptr->graph.version == 1)
{
/* we have empty initial graph, increment graph version,
- so we dont do jack_get_ports() again,
+ so we don't do jack_get_ports() again,
on next next graph change */
patchbay_ptr->graph.version++;
}
diff --git a/doxyfile.in b/doxyfile.in
index 9c5e1680..7226a469 100644
--- a/doxyfile.in
+++ b/doxyfile.in
@@ -657,7 +657,7 @@ EXAMPLE_PATH =
EXAMPLE_PATTERNS =
# If the EXAMPLE_RECURSIVE tag is set to YES then subdirectories will be
-# searched for input files to be used with the \include or \dontinclude
+# searched for input files to be used with the \include or \don'tinclude
# commands irrespective of the value of the RECURSIVE tag.
# Possible values are YES and NO. If left blank NO is used.
diff --git a/example-clients/alsa_in.c b/example-clients/alsa_in.c
index 29e9bf3b..a65a4ea2 100644
--- a/example-clients/alsa_in.c
+++ b/example-clients/alsa_in.c
@@ -106,7 +106,7 @@ alsa_format_t formats[] = {
#define NUMFORMATS (sizeof(formats)/sizeof(formats[0]))
int format=0;
-// Alsa stuff... i dont want to touch this bullshit in the next years.... please...
+// Alsa stuff... i don't want to touch this bullshit in the next years.... please...
static int xrun_recovery(snd_pcm_t *handle, int err) {
// printf( "xrun !!!.... %d\n", err );
diff --git a/example-clients/alsa_out.c b/example-clients/alsa_out.c
index fbfc3dd0..a7b74f47 100644
--- a/example-clients/alsa_out.c
+++ b/example-clients/alsa_out.c
@@ -106,7 +106,7 @@ alsa_format_t formats[] = {
#define NUMFORMATS (sizeof(formats)/sizeof(formats[0]))
int format=0;
-// Alsa stuff... i dont want to touch this bullshit in the next years.... please...
+// Alsa stuff... i don't want to touch this bullshit in the next years.... please...
static int xrun_recovery(snd_pcm_t *handle, int err) {
// printf( "xrun !!!.... %d\n", err );
diff --git a/example-clients/netsource.c b/example-clients/netsource.c
index 9386aecc..6cf8c698 100644
--- a/example-clients/netsource.c
+++ b/example-clients/netsource.c
@@ -244,7 +244,7 @@ alloc_ports (int n_capture_audio, int n_playback_audio, int n_capture_midi, int
/**
* The Sync callback... sync state is set elsewhere...
* we will see if this is working correctly.
- * i dont really believe in it yet.
+ * i don't really believe in it yet.
*/
int
sync_cb (jack_transport_state_t state, jack_position_t *pos, void *arg)
diff --git a/man/alsa_in.0 b/man/alsa_in.0
index 91956a01..6f81ae01 100644
--- a/man/alsa_in.0
+++ b/man/alsa_in.0
@@ -90,7 +90,7 @@ However most CPU time is spent in the resampling so this will not be much.
If you have a PCI card, then the default value (15) of this parameter is too high for \-p64 \-n2... Setting it to 5 should fix that.
Be aware that setting this parameter too low, lets the hf noise on the delay measurement come through onto the resamplerate, so this
might degrade the quality of the output. (but its a threshold value, and it has been chosen, to mask the noise of a USB card,
-which has an amplitude which is 50 times higher than that of a PCI card, so 5 wont loose you any quality on a PCI card)
+which has an amplitude which is 50 times higher than that of a PCI card, so 5 won't lose you any quality on a PCI card)
.SH AUTHOR
Torben Hohn
diff --git a/man/jack_simple_client.0 b/man/jack_simple_client.0
index a3cf16e0..e574a14b 100644
--- a/man/jack_simple_client.0
+++ b/man/jack_simple_client.0
@@ -1,7 +1,7 @@
.TH JACK_CONNECT "1" "!DATE!" "!VERSION!"
.SH NAME
jack_simple_client \- The JACK Audio Connection Kit example client
-.SH SYNOPSYS
+.SH SYNOPSIS
.B jack_simple_client
client-name
.PP
diff --git a/man/jackd.0 b/man/jackd.0
index d64ec0fc..97947617 100644
--- a/man/jackd.0
+++ b/man/jackd.0
@@ -370,7 +370,7 @@ Whether to use Autoconfig, or just start. (default: true)
Send packets N times (default: 1)
.TP
\fB\-e, \-\-native\-endian \fIint\fR
-Dont convert samples to network byte order. (default: false)
+Don't convert samples to network byte order. (default: false)
.TP
\fB\-J, \-\-jitterval \fIint\fR
attempted jitterbuffer microseconds on master (default: 0)
diff --git a/windows/JackWinNamedPipeClientChannel.cpp b/windows/JackWinNamedPipeClientChannel.cpp
index 5bc63a04..8d94b9e5 100644
--- a/windows/JackWinNamedPipeClientChannel.cpp
+++ b/windows/JackWinNamedPipeClientChannel.cpp
@@ -152,7 +152,7 @@ bool JackWinNamedPipeClientChannel::Execute()
return true;
error:
- // Close the pipes, server wont be able to create them otherwise.
+ // Close the pipes, server won't be able to create them otherwise.
fNotificationListenPipe.Close();
fRequest->Close();
fClient->ShutDown(jack_status_t(JackFailure | JackServerError), JACK_SERVER_FAILURE);
diff --git a/common/netjack_packet.c b/common/netjack_packet.c
index cd3a8d6d..e69f8062 100644
--- a/common/netjack_packet.c
+++ b/common/netjack_packet.c
@@ -286,7 +286,7 @@ cache_packet_reset (cache_packet *pack)
int i;
pack->valid = 0;
// XXX: i dont think this is necessary here...
// fragement array is cleared in _set_framecnt()
for (i = 0; i < pack->num_fragments; i++)
@@ -318,7 +318,7 @@ cache_packet_add_fragment (cache_packet *pack, char *packet_buf, int rcv_len)
jack_nframes_t framecnt = ntohl (pkthdr->framecnt);
if (framecnt != pack->framecnt) {
- jack_error ("errror. framecnts dont match");
+ jack_error ("error. framecnts don't match");
return;
}
@@ -286,7 +286,7 @@ cache_packet_reset (cache_packet *pack)
int i;
pack->valid = 0;
- // XXX: i dont think this is necessary here...
+ // XXX: i don't think this is necessary here...
// fragement array is cleared in _set_framecnt()
for (i = 0; i < pack->num_fragments; i++)
diff --git a/tests/test.cpp b/tests/test.cpp
index d2ef9a05..b355ec64 100644
--- a/tests/test.cpp
+++ b/tests/test.cpp
@@ -1576,15 +1576,15 @@ int main (int argc, char *argv[])
* (This mode seems to be problematic in standard jack version 0.100. It seems that nobody
* is used to apply this mode because the tie mode doesn't work at all. A patch seems difficult to produce
* in this version of jack. Tie mode work well in MP version.)
* Test some basic thinks (tie with 2 differents client, tie non-owned ports...)
* Tie client1.in1 and client1.out1 ports, and make some data test to check the validity of the tie.
*
*/
Log("Testing tie mode...\n");
if (jack_port_tie(input_port1, output_port2) != 0) {
- Log("not possible to tie two ports from two differents clients... ok\n");
+ Log("not possible to tie two ports from two different clients... ok\n");
} else {
- printf("!!! ERROR !!! port_tie has allowed a connexion between two differents clients !\n");
+ printf("!!! ERROR !!! port_tie has allowed a connexion between two different clients !\n");
jack_port_untie(output_port2);
}
Log("Testing connections datas in tie mode...\n");
@@ -1576,15 +1576,15 @@ int main (int argc, char *argv[])
* is used to apply this mode because the tie mode doesn't work at all. A patch seems difficult to produce
* in this version of jack. Tie mode work well in MP version.)
- * Test some basic thinks (tie with 2 differents client, tie non-owned ports...)
+ * Test some basic thinks (tie with 2 different client, tie non-owned ports...)
* Tie client1.in1 and client1.out1 ports, and make some data test to check the validity of the tie.
*